@@ -193,6 +193,12 @@ if [ -f "$DESTDIR/usr/lib/pm-utils/sleep.d/99laptop-mode" ]; then
 	rm -f $DESTDIR/usr/lib/pm-utils/sleep.d/99laptop-mode;
 fi
 
+# udev rule
+if ( ! $INSTALL -D -m 644 etc/rules/99-laptop-mode.rules "$DESTDIR/etc/udev/rules.d/99-laptop-mode.rules" ) ; then
+    echo "$0: Failed to install udev rule into /etc/udev/rules.d/ Installation failed."
+    exit 23
+fi
+
 ACPI_DONE=0
 APM_DONE=0
 PMU_DONE=0
